@@ -1,15 +1,16 @@
-from pathlib import Path
-import responses  # type: ignore
-import json
 import gzip
+import json
 import os
 import sys
 import tempfile
-from launchable.utils.session import read_session, write_build
-from launchable.utils.http_client import get_base_url
-from tests.cli_test_case import CliTestCase
+from pathlib import Path
 from unittest import mock
 
+import responses  # type: ignore
+from launchable.utils.http_client import get_base_url
+from launchable.utils.session import read_session, write_build
+from tests.cli_test_case import CliTestCase
+
 
 class RawTest(CliTestCase):
     @responses.activate
@@ -108,7 +109,10 @@ class RawTest(CliTestCase):
             self.assert_json_orderless_equal(payload, {
                 'events': [
                     {
-                        'testPath': 'file=a.py#class=classA',
+                        'testPath': [
+                            {'type': 'file', 'name': 'a.py'},
+                            {'type': 'class', 'name': 'classA'},
+                        ],
                         'duration': 42,
                         'status': 1,
                         'stdout': 'This is stdout',
